@@ -26,21 +26,6 @@
 
 function [Q,I] = qarts
  
-%-----------------------------------------------------------------------------
-Q.ABSORPTION = {};
-I.ABSORPTION = [ ...
-'String describing how absorption shall be calculated/obtained. ',...
-'Existing options are:', ...
-'#    {}        : Absorption variables defined by include files. All ',...
-'absorption fields below will be ignored.',...    
-'#   ''OnTheFly'' : Absorption is calculated for each propagation path ',...
-'point. The agenda *abs_scalar_gas_agenda* must here be set by an include ',...
-'file. No other absorption variables need to be set.',...
-'#   ''CalcTable'': Calculate and use an absorption look-up table. See ',...
-'*qarts_abstable* for simple setting of needed variables.',...
-'#   ''LoadTable'': Load and use pre-calculated absorption look-up table, ',...
-'defined by field *ABS_LOOKUP*.',
-];
 %-----------------------------------------------------------------------------
 Q.ABS_LINES = {};
 I.ABS_LINES = [ ...
@@ -141,7 +126,8 @@ I.ABS_SPECIES = [ ...
 'given to arts, it can only be used to set-up *VMR_FIELD*. This step is ',...
 'handled by *qarts_vmr_field*. The field is accordingly not mandatory. ',...
 'The main usage of this field should be to import data of climatology ',...
-'character. Can be given as a variable or a file saved through *gf_save*.', ...
+'character. Can be given as a variable or a file saved through *gf_save*. ',...
+'This field is recognised and used automatically by Qpack2.',...
 '# ',...
 '#<RETRIEVE> If set to true the species is retrieved. Otherwise the ', ...
 'species is not retrieved (what a surprise!).', ...
@@ -184,7 +170,15 @@ I.ABS_SPECIES = [ ...
 'data.',...
 '# Only retrieved profile and errors are modified. Averaging kernel, ',...
 'covariance and gain matrices are kept consistent with the original ',...
-'retrieval grids.'
+'retrieval grids.'...
+'# ',...
+'#<MINMAX> Min and max allowed value for retrievals. A single min and ',...
+'max value is applied for each species. The field can be left undefined, ',...
+'be empty, be a scalar or vector of length 2. A single value as taken as ',...
+'min, and is then set to Inf. The min value can be set to -Inf. The unit',...
+'follows the field *UNIT*.',...
+'# The primary usage of the field should be to avoid negative vmr values. ',...
+'(The limits are applied also during the iterations of a non-linear inversion.'
 ];
 %-----------------------------------------------------------------------------
 Q.ABS_T = {};
@@ -216,7 +210,34 @@ I.ABS_VMRS = [ ...
 %-----------------------------------------------------------------------------
 Q.ABS_WSMS = {};
 I.ABS_WSMS = [ ...
-'Workspace method calls to include just before calculation of absorption.'
+'Workspace method calls to include just before calculation of absorption. ',...
+'Format and options as WSMS_AT_START.'
+];
+%-----------------------------------------------------------------------------
+Q.ABS_XSEC_AGENDA = {};
+I.ABS_XSEC_AGENDA = [ ...
+'As the arts WSV with the same name. WSMs are listed as an array of ',...
+'strings.',...
+'#   If the field *ABSORPTION* is set, this agenda is set to its most ',...
+'common choice. Accordingly, this field is only needed if your ',...
+'calculations require a deviating agenda definition.'
+];
+%-----------------------------------------------------------------------------
+Q.ABSORPTION = {};
+I.ABSORPTION = [ ...
+'String describing how absorption shall be calculated/obtained. ',...
+'Existing options are:', ...
+'#    {}        : Absorption variables defined by include files. All ',...
+'absorption fields above will be ignored.',...    
+'#   ''OnTheFly'' : Absorption is calculated for each propagation path ',...
+'point. The agenda *abs_scalar_gas_agenda* must here be set by an include ',...
+'file. No other absorption variables need to be set.',...
+'#   ''CalcTable'': Calculate and use an absorption look-up table. See ',...
+'*qarts_abstable* for simple setting of needed variables.',...
+'#   ''LoadTable'': Load and use pre-calculated absorption look-up table, ',...
+'defined by field *ABS_LOOKUP*.',...
+'#If this field is set, *ABS_XSEC_AGENDA* and *PROPMAT_CLEARSKY_AGENDA* ',...
+'are set matching calculations of standard type.'
 ];
 %-----------------------------------------------------------------------------
 Q.ANTENNA_DIM = {};
@@ -238,6 +259,17 @@ I.BATCH = [ ...
 'must be selected specifically (most easily done by using *arts_batch*).' 
 ];
 %-----------------------------------------------------------------------------
+Q.BLACKBODY_RADIATION_AGENDA = {};
+I.BLACKBODY_RADIATION_AGENDA = [ ...
+'As the arts WSV with the same name. WSMs are listed as an array of strings.'
+];
+%-----------------------------------------------------------------------------
+Q.CLOUDBOX = {};
+I.CLOUDBOX = [ ...
+'Handling of cloudbox/scattering. Defined by a structure, described in ',...
+'*qartsCloudbox*. Type ''qinfo(@qartsCloudbox);'' for further information.'
+];
+%-----------------------------------------------------------------------------
 Q.CLOUDBOX_DO = {};
 I.CLOUDBOX_DO = [ ...
 'Boolean to activate the cloud box (scattering calculations), or not.',...
@@ -247,18 +279,6 @@ I.CLOUDBOX_DO = [ ...
 '#    1: Action follows setting of field *CLOUDBOX*.'
 ];
 %-----------------------------------------------------------------------------
-Q.CLOUDBOX = {};
-I.CLOUDBOX = [ ...
-'Handling of cloudbox/scattering. Defined by a structure, described in ',...
-'*qartsCloudbox*. Type ''qinfo(@qartsCloudbox);'' for further information.'
-];
-%-----------------------------------------------------------------------------
-Q.EMISSION_AGENDA = {};
-I.EMISSION_AGENDA = [ ...
-'As the arts WSV with the same name.', ...
-' WSMs are listed as an array of strings, with possible arguments.'
-];
-%-----------------------------------------------------------------------------
 Q.F_GRID = {};
 I.F_GRID = [ ...
 'Has the same functionality as the arts WSV with the same name.', ...
@@ -266,20 +286,37 @@ I.F_GRID = [ ...
 'variable.'
 ];
 %-----------------------------------------------------------------------------
-Q.FFIT = {};
-I.FFIT = [ ...
-'Structure for specification of frequency fit retrievals. No retrieval is ',...
-'made if field is empty or sub-field RETRIEVAL is set to false. The WSM ',...
-'used is *jacobianAddFreqShiftAndStretch*. These sub-fields are defined:',...
+Q.FSHIFTFIT = {};
+I.FSHIFTFIT = [ ...
+'Structure for specification of frequency shift retrievals. No retrieval',...
+'is made if field is empty or sub-field RETRIEVAL is set to false. The WSM ',...
+'used is *jacobianAddFreqShift*. The polynomial order is hard-coded to ',...
+'zero. These sub-fields are defined:',...
 '# ',...
 '#<RETRIEVE> Flag to activate frequency retrieval.', ...    
 '# ',...
-'#<DF> Size for numerical perturbation. See used WSM.', ...
+'#<DF> Size for numerical perturbation.', ...
 '# ',...
-'#<ORDER> Order of frequency fit, max value is 1 (0=shift, 1=stretch).', ...
+'#<SX> Variance of a priori knowledge on the variable.',...
 '# ',...
-'#<SX> Covariance matrix of a priori knowledge for frequency shift and ',...
-'stretch. A 1x1 or 2x2 matrix, depending on ORDER.',...
+'#<L2> Flag for any function creating L2 data. See comments for ',...
+'*L2_EXTRA*. If set to true, the retrieved frequency fit variables ',...
+'will be included in the L2 output. Otherwise not. This field has no ',...
+'importance if RETRIEVE is false.'
+];
+%-----------------------------------------------------------------------------
+Q.FSTRETCHFIT = {};
+I.FSTRETCHFIT = [ ...
+'Structure for specification of frequency stretch retrievals. No retrieval ',...
+'is made if field is empty or sub-field RETRIEVAL is set to false. The WSM ',...
+'used is *jacobianAddFreqStretch*. The polynomial order is hard-coded to ',...
+'zero. These sub-fields are defined:',...
+'# ',...
+'#<RETRIEVE> Flag to activate frequency retrieval.', ...    
+'# ',...
+'#<DF> Size for numerical perturbation.', ...
+'# ',...
+'#<SX> Variance of a priori knowledge on the variable.',...
 '# ',...
 '#<L2> Flag for any function creating L2 data. See comments for ',...
 '*L2_EXTRA*. If set to true, the retrieved frequency fit variables ',...
@@ -304,14 +341,14 @@ I.HSE = [ ...
 'to false. Note the setting Q.T.HSE which controls the calculation of t-',...
 'jacobians. The two settings are treated as independent, but should ',...
 'be set to the same value (true/false). If the HSE is maintained during ',...
-'the iterations of a temperature retrieval is controled by THIS field.'
+'the iterations of a temperature retrieval is controlled by THIS field.'
 ];    
 %-----------------------------------------------------------------------------
 Q.INCLUDES = {};
 I.INCLUDES = [ ...
 'Paths to control files to be included. These files will be included ',...
 'at the top of the control file, only preceded by WSMS_AT_START. Given ',...
-'as an array of strings.',...
+'as an array of strings. Format and options as for WSMS_AT_START.',...
 '#   The atmlab setting ARTS_INCLUDES is recognised. To include the ',...
 'standard arts general definition file, select:',...
 '{''ARTS_INCLUDES/general.arts''}'
@@ -320,24 +357,54 @@ I.INCLUDES = [ ...
 Q.INPUT_FILE_FORMAT = 'binary';
 I.INPUT_FILE_FORMAT = [ ...
 'The file format for arts input files. That is, the format of the files ',...
-'created in matlab to be read by arts. Possible options are ''binary'', '...
+'created in Matlab to be read by arts. Possible options are ''binary'', '...
 'and ''double''. The binary option, that is default, should be most '...
 'efficient. Use ''double'' if you want to visually inspect the files ',...
 'generated. (The option ''float'' is not allowed, as this is not always '...
 'sufficient for frequency data.)'
 ];
 %-----------------------------------------------------------------------------
-Q.IY_CLEARSKY_AGENDA = {};
-I.IY_CLEARSKY_AGENDA = [ ...
-'As the arts WSV with the same name.', ...
-' WSMs are listed as an array of strings.'
+Q.IY_AUX_VARS = {};
+I.IY_AUX_VARS = [ ...
+'As the arts WSV with the same name.'
+];
+%-----------------------------------------------------------------------------
+Q.IY_MAIN_AGENDA = {};
+I.IY_MAIN_AGENDA = [ ...
+'As the arts WSV with the same name. WSMs are listed as an array of strings.'
 ];
 %-----------------------------------------------------------------------------
 Q.IY_SPACE_AGENDA = {};
 I.IY_SPACE_AGENDA = [ ...
-'As the arts WSV with the same name. ', ...
-'WSMs are listed as an array of strings, with possible arguments. ', ...
-'See PPATH_STEP_AGENDA for a practical example on format to use.'
+'As the arts WSV with the same name. WSMs are listed as an array of strings.'
+
+];
+%-----------------------------------------------------------------------------
+Q.IY_SUB_AGENDA = {};
+I.IY_SUB_AGENDA = [ ...
+'As the arts WSV with the same name. WSMs are listed as an array of strings.'
+];
+%-----------------------------------------------------------------------------
+Q.IY_SURFACE_AGENDA = {};
+I.IY_SURFACE_AGENDA = [ ...
+'As the arts WSV with the same name. WSMs are listed as an array of strings.'
+];
+%-----------------------------------------------------------------------------
+Q.IY_TRANSMITTER_AGENDA = {};
+I.IY_TRANSMITTER_AGENDA = [ ...
+'As the arts WSV with the same name. WSMs are listed as an array of strings.'
+];
+%-----------------------------------------------------------------------------
+Q.IY_UNIT = {};
+I.IY_UNIT = [ ...
+'As the arts WSV with the same name. That is, the radiance unit. ',...
+'The options include:', ...
+'#   ''1''       : Basic radiances [W/m2/Hz/sr]',...
+'#   ''RJBT''    : Conversion to brightness temperature by the Rayleigh-',...
+'Jeans approximation of the Planck function.',...
+'#   ''PlanckBT'': Conversion to brightness temperature by the Planck ',...
+    'function.',...
+'#For further information: ''arts -d iy_unit''.'
 ];
 %-----------------------------------------------------------------------------
 Q.J_DO = {};
@@ -351,24 +418,32 @@ I.J_DO = [ ...
 %-----------------------------------------------------------------------------
 Q.LAT_GRID = {};
 I.LAT_GRID = [ ...
-'Has the same functionality as the arts WSV with the same name, with the ', ...
-'difference that a scalar value is accepted when ATMOSPHERE_DIM = 1. It ',...
-'could be needed to set such a scalar value when *qarts_vmr_field* and ',...
-'similar functions are used.',...
+'As the arts WSV with the same name. For example, shall be empty for 1D ', ...
+'simulations.',...
 '#   Can be given either as the name of a XML file, or as a matching ',...
 'Matlab variable.'
 ];
 %-----------------------------------------------------------------------------
+Q.LAT_TRUE = {};
+I.LAT_TRUE = [ ...
+'As the arts WSV with the same name. Can be given either as the name of ',...
+'a XML file, or as a matching Matlab variable.'
+];
+%-----------------------------------------------------------------------------
 Q.LON_GRID = {};
 I.LON_GRID = [ ...
-'Has the same functionality as the arts WSV with the same name, with the ', ...
-'difference that a scalar value is accepted when ATMOSPHERE_DIM = 1. It ',...
-'could be needed to set such a scalar value when *qarts_vmr_field* and ',...
-'similar functions are used.', ...
+'As the arts WSV with the same name. For example, shall be empty for 1D ', ...
+'and 2D simulations.',...
 '#   Can be given either as the name of a XML file, or as a matching ',...
 'Matlab variable.'
 ];
 %-----------------------------------------------------------------------------
+Q.LON_TRUE = {};
+I.LON_TRUE = [ ...
+'As the arts WSV with the same name. Can be given either as the name of ',...
+'a XML file, or as a matching Matlab variable.'
+];
+%-----------------------------------------------------------------------------
 Q.L2_EXTRA = {};
 I.L2_EXTRA = [ ...
 'Information to functions repacking retrieval information. Such a product ', ...
@@ -380,6 +455,54 @@ I.L2_EXTRA = [ ...
 'coding) differs between the functions.'
 ];
 %-----------------------------------------------------------------------------
+Q.MAG_U_FIELD = {};
+I.MAG_U_FIELD = [ ...
+'As the arts WSV with the same name. Can be set to [].', ...
+'#   Can be given either as the name of a XML file, or as a matching ',...
+'Matlab variable.'
+];
+%-----------------------------------------------------------------------------
+Q.MAG_U = {};
+I.MAG_U = [ ...
+'Data and settings associated with MAG_U_FIELD. Has the same role as T with ',...
+'respect to T_FIELD, but as there are no retrievals associated with MAG_U ',...
+'there is only one sub-field here:',...
+'# ',...
+'#<ATMDATA> The input shall follow the atmdata format, defined in ',...
+'*isatmdata*. The data specified here are not directly given to arts, it ',...
+'can only be used to set-up *MAG_U_FIELD*. This step is handled by ',...
+'*qarts_atm_field*. The main usage of this field should be to import ',...
+'data of climatology character. Can be given as a variable or a file saved ',...
+'through *gf_save*. ',...
+'This field is recognised and used automatically by Qpack2.',...
+];
+%-----------------------------------------------------------------------------
+Q.MAG_V_FIELD = {};
+I.MAG_V_FIELD = [ ...
+'As the arts WSV with the same name. Can be set to [].', ...
+'#   Can be given either as the name of a XML file, or as a matching ',...
+'Matlab variable.'
+];
+%-----------------------------------------------------------------------------
+Q.MAG_V = {};
+I.MAG_V = [ ...
+'Data and settings associated with the v-component of the magnetic field. ',...
+'Defined as MAG_U, and the details are nor repeated here.'
+];
+%-----------------------------------------------------------------------------
+Q.MAG_W_FIELD = {};
+I.MAG_W_FIELD = [ ...
+'As the arts WSV with the same name. Can be set to [].', ...
+'#   Can be given either as the name of a XML file, or as a matching ',...
+'Matlab variable.'
+];
+%-----------------------------------------------------------------------------
+Q.MAG_W = {};
+I.MAG_W = [ ...
+'Data and settings associated with the w-component of the magnetic field. ',...
+'Defined as MAG_U, and the details are nor repeated here.'
+];
+%-----------------------------------------------------------------------------
 Q.MBLOCK_AA_GRID = {};
 I.MBLOCK_AA_GRID = [ ...
 'Has the same functionality as the arts WSV with the same name. ', ...
@@ -406,20 +529,30 @@ I.OUTPUT_FILE_FORMAT = [ ...
 'should in general be most efficient.'
 ];
 %-----------------------------------------------------------------------------
+Q.P_GRID = {};
+I.P_GRID = [ ...
+'Has the same functionality as the arts WSV with the same name.', ...
+'#   Can be given either as the name of a XML file, or as a matching ',...
+'Matlab variable.'
+];
+%-----------------------------------------------------------------------------
 Q.POINTING = {};
 I.POINTING = [ ...
 'Structure for specification of pointing fit retrievals. No retrieval is', ...
 'made if field is empty or sub-field RETRIEVAL is set to false. The WSM ',...
-'used is *jacobianAddPointing*. These sub-fields are defined:',...
+'used is *jacobianAddPointingZa*. These sub-fields are defined:',...
 '# ',...
 '#<RETRIEVE> Flag to activate pointing retrieval.', ...    
 '# ',...
 '#<DZA> Size for numerical perturbation. See used WSM.', ...
 '# ',...
-'#<POLY_ORDER> Order of polynomial to describe pointing errors. ', ...
+'#<POLY_ORDER> Order of polynomial to describe the time variation of ',...
+'pointing errors.', ...
+'# ',...
+'#<CALCMODE> The manner in which the jacobian is determined. See  used WSM',...
 '# ',...
 '#<SX> Covariance matrix of a priori knowledge for pointing fit variables. ',...
-'A square matrix with POLY_ORDER+1.',...
+'A square matrix of size POLY_ORDER+1.',...
 '# ',...
 '#<L2> Flag for any function creating L2 data. See comments for ',...
 '*L2_EXTRA*. If set to true, the retrieved pointing variables ',...
@@ -451,6 +584,11 @@ I.POLYFIT = [ ...
 'importance if RETRIEVE is false.'
 ];
 %-----------------------------------------------------------------------------
+Q.PPATH_AGENDA = {};
+I.PPATH_AGENDA = [ ...
+'As the arts WSV with the same name. WSMs are listed as an array of strings.'
+];
+%-----------------------------------------------------------------------------
 Q.PPATH_LMAX = {};
 I.PPATH_LMAX = [ ...
 'As the arts WSV with the same name .', ...
@@ -467,47 +605,43 @@ I.PPATH_LRAYTRACE = [ ...
 %-----------------------------------------------------------------------------
 Q.PPATH_STEP_AGENDA = {};
 I.PPATH_STEP_AGENDA = [ ...
-'As the arts WSV with the same name.', ...
-'WSMs are listed as an array of strings. ', ...
-'An example showing how an agenda definition looks like:', ...
-'#   Q.PPATH_STEP_AGENDA={''ppath_stepGeometric''}' 
+'As the arts WSV with the same name. WSMs are listed as an array of strings.'
 ];
 %-----------------------------------------------------------------------------
-Q.P_GRID = {};
-I.P_GRID = [ ...
-'Has the same functionality as the arts WSV with the same name.', ...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
-];
-%-----------------------------------------------------------------------------
-Q.R_GEOID = {};
-I.R_GEOID = [ ...
-'Geoid radius. As the arts WSV with the same name .'
+Q.PROPMAT_CLEARSKY_AGENDA = {};
+I.PROPMAT_CLEARSKY_AGENDA = [ ...
+'As the arts WSV with the same name. WSMs are listed as an array of ',...
+'strings.',...
+'#   If the field *ABSORPTION* is set, this agenda is set to its most ',...
+'common choice (for the selected ABSORPTION option). Accordingly, this ',...
+'field is only needed if your calculations require a deviating agenda ',...
+'definition.'
 ];
 %-----------------------------------------------------------------------------
 Q.RAW_ATMOSPHERE = {};
 I.RAW_ATMOSPHERE = [ ...
-'If set a "raw atmosphere" in read. This is the main file name for the ',...
-'raw atmosphere. See further ''arts -d AtmRawRead''. ',...
+'If set, a "raw atmosphere" in read. This is the main file name for the ',...
+'raw atmosphere. See further ''arts -d AtmRawRead''.',...
 '#Data in the fields T_FIELD, Z_FIELD or VMR_FIELD are included at a later ',...
 'stage and will then overwrite the data from the raw atmosphere. This ',...
-'thus some flexibility to mix data from different sources.'
+'gives thus some flexibility to mix data from different sources.'
 ];
 %-----------------------------------------------------------------------------
 Q.RAW_ATM_EXPAND_1D = {};
 I.RAW_ATM_EXPAND_1D = [ ...
 'Boolean to expand an 1D raw atmosphere to set ATMOSPHERE_DIM. If set to ',...
-' 1, the WSM *AtmFieldsCalcExpand1D* is used instead of *AtmFieldsCalc*.',...
+'1, the WSM *AtmFieldsCalcExpand1D* is used instead of *AtmFieldsCalc*.',...
 'This variable is only used if RAW_ATMOSPHERE is set.'
 ];
 %-----------------------------------------------------------------------------
-Q.REFR_INDEX_AGENDA = {};
-I.REFR_INDEX_AGENDA = [ ...
-'As the arts WSV with the same name. ', ...
-'If PPATH_STEP_AGENDA does not involve refraction, this field can be ', ...
-'left as {}.',...
-'#    WSMs are listed as an array of strings. ', ...
-'See PPATH_STEP_AGENDA for a practical example on format to use.' 
+Q.REFELLIPSOID = {};
+I.REFELLIPSOID = [ ...
+'Reference ellipsoid. As the arts WSV with the same name .'
+];
+%-----------------------------------------------------------------------------
+Q.REFR_INDEX_AIR_AGENDA = {};
+I.REFR_INDEX_AIR_AGENDA = [ ...
+'As the arts WSV with the same name. WSMs are listed as an array of strings.'
 ];
 %-----------------------------------------------------------------------------
 Q.SENSOR_DO = {};
@@ -611,16 +745,47 @@ I.SENSOR_RESPONSE_ZA_GRID = [ ...
 'Matlab variable.'
 ];
 %-----------------------------------------------------------------------------
+Q.SENSOR_TIME = {};
+I.SENSOR_TIME = [ ...
+'As the arts WSV with the same name.'
+];
+%-----------------------------------------------------------------------------
+Q.SINEFIT = {};
+I.SINEFIT = [ ...
+'Structure for specification of sinusoidal baseline fits. No retrieval is', ...
+'made if field is empty or sub-field RETRIEVAL is set to false. The WSM ',...
+'used is *jacobianAddSinefit*. All no_xxx_variation arguments of the WSM ',...
+'are set to default value. The different period lengths are assumed ',...
+'to be uncorrelated. These sub-fields are defined:',...
+'# ',...
+'#<RETRIEVE> Flag to activate retrieval', ...    
+'# ',...
+'#<PERIODS> Period lengths of the fit.', ...
+'# ',...
+'#<SX1> Covariance matrix of a priori knowledge for coefficients of first ',...
+'period length. This is applied as the covariance for both the sine and ',...
+'cosine term, assuming that the two terms are uncorrelated. That is, for ',...
+'single spectra retrievals, SX1 is a scalar, giving the variance for both ',...
+'a and b, where the baseline is modelled as a*sin(...)+b*cos(...). ',...
+'There shall be such a matrix for each period length until:',...
+'# ',...
+'#<SXn> Covariance matrix of a priori knowledge for last period length. ',...
+'The last required covariance matrix.',...
+'# ',...
+'#<L2> Flag for any function creating L2 data. See comments for ',...
+'*L2_EXTRA*. If set to true, the retrieved baseline variables ',...
+'will be included in the L2 output. Otherwise not. This field has no ',...
+'importance if RETRIEVE is false.'
+];
+%-----------------------------------------------------------------------------
 Q.STOKES_DIM = {};
 I.STOKES_DIM = [ ...
 'As the arts WSV with the same name.'
 ];
 %-----------------------------------------------------------------------------
-Q.SURFACE_PROP_AGENDA = {};
-I.SURFACE_PROP_AGENDA = [ ...
-'As the arts WSV with the same name.', ...
-' WSMs are listed as an array of strings.', ...
-' See PPATH_STEP_AGENDA for a practical example on format to use.' 
+Q.SURFACE_RTPROP_AGENDA = {};
+I.SURFACE_RTPROP_AGENDA = [ ...
+'As the arts WSV with the same name. WSMs are listed as an array of strings.'
 ];
 %-----------------------------------------------------------------------------
 Q.T = {};
@@ -631,9 +796,10 @@ I.T = [ ...
 '#<ATMDATA> The input shall follow the atmdata format, defined in ',...
 '*isatmdata*. The data specified here are not directly given to arts, it ',...
 'can only be used to set-up *T_FIELD*. This step is handled by ',...
-'*qarts_t_or_z_field*. The main usage of this field should be to import ',...
+'*qarts_atm_field*. The main usage of this field should be to import ',...
 'data of climatology character. Can be given as a variable or a file saved ',...
-'through *gf_save*.',...
+'through *gf_save*. ',...
+'This field is recognised and used automatically by Qpack2.',...
 '# ',...
 '#<RETRIEVE> If set to true, atmospheric temperatures are retrieved.', ...
 '# ',...
@@ -651,9 +817,12 @@ I.T = [ ...
 '# ',...
 '#<L2_RANGE>  As the same field for ABS_SPECIES.',...
 '# ',...
+'#<MINMAX> Min and max allowed value for retrievals. Works exactly as ',...
+'for ABS_SPECIES.',...
+'# ',...
 '#<HSE> As the argument to *jacobianAddTemperature* with same name. ',...
 'Default here is "on". This refers only to the actual jacobian calculation.',...
-' If the atmosphere itself fulfils HSE or not is controled by Q.HSE.',...
+' If the atmosphere itself fulfils HSE or not is controlled by Q.HSE.',...
 '# ',...
 '#<METHOD> As the argument to *jacobianAddTemperature* with same name. ',...
 'Default here is "analytical".',...
@@ -682,6 +851,18 @@ I.TNOISE_C = [ ...
 's*s*TNOISE_C.'
 ];
 %-----------------------------------------------------------------------------
+Q.TRANSMITTER_POS = {};
+I.TRANSMITTER_POS = [ ...
+'As the arts WSV with the same name.'
+];
+%-----------------------------------------------------------------------------
+Q.VMR_NEGATIVE_OK = {};
+I.VMR_NEGATIVE_OK = [ ...
+'Corresponds directly to the argument *negative_vmr_ok* of ',...
+'*atmfields_checkedCalc*. Default is false, and only needed if you want ',...
+'to the flag to true.'
+];
+%-----------------------------------------------------------------------------
 Q.VMR_FIELD = {};
 I.VMR_FIELD = [ ...
 'As the arts WSV with the same name. Will replace VMR data inserted ',...
@@ -692,6 +873,39 @@ I.VMR_FIELD = [ ...
 'by this field.'
 ];
 %-----------------------------------------------------------------------------
+Q.WIND_U = {};
+I.WIND_U = [ ...
+'Data and settings associated with the u-component of winds. Normally used ',...
+'when retrieving winds. Otherwise, *WIND_U_FIELD* can be set directly.',...
+'# ',...
+'#<ATMDATA> The input shall follow the atmdata format, defined in ',...
+'*isatmdata*. The data specified here are not directly given to arts, it ',...
+'can only be used to set-up *WIND_U_FIELD*. This step is handled by ',...
+'*qarts_atm_field*. The main usage of this field should be to import ',...
+'data of climatology character. Can be given as a variable or a file saved ',...
+'through *gf_save*. ',...
+'This field is recognised and used automatically by Qpack2.',...
+'# ',...
+'#<RETRIEVE> If set to true, this atmospheric wind is retrieved.', ...
+'# ',...
+'#<GRIDS> Retrieval grids for the wind. An array of vectors of length 3:',...
+' {p_grid,lat_grid,lon_grid}. Grids for dimensions not used shall be ',...
+'empty.',...
+'# ',...
+'#<SX> Covariance matrix of a priori knowledge for temperature. Size must ',...
+'match the grid field. Data must match <UNIT>. A matrix, that can be ',...
+'sparse.',...
+'# ',...
+'#<L2> Flag for any function creating L2 data. See comments for ',...
+'*L2_EXTRA*. If set to true, the retrieved state for this wind component ',...
+'will be included in the L2 output. Otherwise not.',...
+'# ',...
+'#<L2_RANGE>  As the same field for ABS_SPECIES.',...
+'# ',...
+'#None of the fields are mandatory for pure forward calculations. If ',...
+'RETRIEVAL is set to false, the other retrieval related fields are ignored.'
+];  
+%-----------------------------------------------------------------------------
 Q.WIND_U_FIELD = {};
 I.WIND_U_FIELD = [ ...
 'As the arts WSV with the same name. Can be set to [].', ...
@@ -699,6 +913,12 @@ I.WIND_U_FIELD = [ ...
 'Matlab variable.'
 ];
 %-----------------------------------------------------------------------------
+Q.WIND_V = {};
+I.WIND_V = [ ...
+'Data and settings associated with the v-component of winds. Defined ',...
+'as WIND_U, and the details are nor repeated here.'
+];
+%-----------------------------------------------------------------------------
 Q.WIND_V_FIELD = {};
 I.WIND_V_FIELD = [ ...
 'As the arts WSV with the same name. Can be set to [].', ...
@@ -706,6 +926,12 @@ I.WIND_V_FIELD = [ ...
 'Matlab variable.'
 ];
 %-----------------------------------------------------------------------------
+Q.WIND_W = {};
+I.WIND_W = [ ...
+'Data and settings associated with the w-component of winds. Defined ',...
+'as WIND_U, and the details are nor repeated here.'
+];
+%-----------------------------------------------------------------------------
 Q.WIND_W_FIELD = {};
 I.WIND_W_FIELD = [ ...
 'As the arts WSV with the same name. Can be set to [].', ...
@@ -716,24 +942,42 @@ I.WIND_W_FIELD = [ ...
 Q.WSMS_AT_END = {};
 I.WSMS_AT_END = [ ...
 'Workspace method calls to include at the far end of the control file. ',...
-'As WSMS_AT_START beside position in control file.'
+'Format and options as for WSMS_AT_START.'
 ];
 %-----------------------------------------------------------------------------
 Q.WSMS_AT_START = {};
 I.WSMS_AT_START = [ ...
 'Workspace method calls to include at the top of the control file. These ',...
-'calls will be executed before inclusion of files specified in INCLUDES.',...
-'#Method calls are specified as an cell array of strings. For example, if ', ...
+'calls are only preceded by possible settings set by INCLUDES.',...
+'# Method calls are specified as an cell array of strings. For example, if ',...
 'no inclusion files are used, these calls could be useful to include',...
-'#   { ''VectorSet(abs_n2,[0.7808])'', ''abs_cont_descriptionInit'' }'
+'#   { ''VectorSet(abs_n2,[0.7808])'', ''abs_cont_descriptionInit'' }',...
+'#A simple if/else/end feature is supported, with the format shown below. ',...
+'The argument to the if-statement must be a field of Q that is a boolean. ',...
+'Nested if-statements are not allowed. An example:',...
+'#   <IF> J_DO',...
+'#    (something)',...
+'#   <ELSE>',...
+'#    (something else)',...
+'#   <END>',...
+'#That is, <IF>, <ELSE> and <END> are used as identifiers. The identifiers ',...
+'must start the line. For <ELSE> and <END>, the rest of the line must be ',...
+'empty.'
+];
+%-----------------------------------------------------------------------------
+Q.WSMS_BEFORE_ATMSURF = {};
+I.WSMS_BEFORE_ATMSURF = [ ...
+'Workspace method calls to include just before setting up the atmosphere ',...
+'and the surface. That is, before consider e.g. Q.P_GRID, Q.T_FIELD, ',...
+'Q.Z_SURFACE. Format and options as for WSMS_AT_START.'
 ];
 %-----------------------------------------------------------------------------
 Q.WSMS_BEFORE_RTE = {};
 I.WSMS_BEFORE_RTE = [ ...
-'Workspace method calls to include just before execution of *YCALC_WSMS* or ',...
-'batch core part. Accordingly, this field is considered only if ',...
+'Workspace method calls to include just before execution of *YCALC_WSMS* ',...
+'or batch core part. Accordingly, this field is considered only if ',...
 'spectra are calculated (ignored for e.g. pure absorption calculations). ',...
-'Format as for WSMS_AT_START.'
+'Format and options as for WSMS_AT_START.'
 ];
 %-----------------------------------------------------------------------------
 Q.YCALC_WSMS = {};
@@ -744,28 +988,23 @@ I.YCALC_WSMS = [ ...
 'for best flexibility this field should start with *yCalc* (or corresponding',...
 ' method), followed by post-processing not handled by other fields.',...
 '#   Accordingly, this field is considered only if spectra are calculated ',...
-'(ignored for e.g. pure absorption calculations). Format as for WSMS_AT_START.'
+'(ignored for e.g. pure absorption calculations). Format and options as ',...
+'for WSMS_AT_START.'
 ];
 %-----------------------------------------------------------------------------
-Q.Y_UNIT = {};
-I.Y_UNIT = [ ...
-'As the arts WSV with the same name. That is, the radiance unit. ',...
-'The following options exist:', ...
-'#   ''1''       : Basic radiances [W/m2/Hz/sr]',...
-'#   ''RJBT''    : Conversion to brightness temperature by the Rayleigh-',...
-'Jeans approximation of the Planck function.',...
-'#   ''PlanckBT'': Conversion to brightness temperature by the Planck ',...
-    'function.',...
-'#For further information: ''arts -d y_unit''.'
-];
-%-----------------------------------------------------------------------------
-Q.Z_ATMDATA = {};
-I.Z_ATMDATA = [ ...
-'The input shall follow the atmdata format, defined in *isatmdata*. The ',...
-'data specified here are not directly given to arts, it can only be used ',...
-'to set-up *Z_FIELD*. This step is handled by *qarts_t_or_z_field*. ',...
-'The main usage of this field should be to import data of climatology ',...
-'character. Can be given as a variable or a file saved through *gf_save*.'
+Q.Z = {};
+I.Z = [ ...
+'Data and settings associated with Z_FIELD. Has the same role as T with ',...
+'respect to T_FIELD, but as there are no retrievals associated with Z ',...
+'there is only one sub-field here:',...
+'# ',...
+'#<ATMDATA> The input shall follow the atmdata format, defined in ',...
+'*isatmdata*. The data specified here are not directly given to arts, it ',...
+'can only be used to set-up *Z_FIELD*. This step is handled by ',...
+'*qarts_atm_field*. The main usage of this field should be to import ',...
+'data of climatology character. Can be given as a variable or a file saved ',...
+'through *gf_save*. ',...
+'This field is recognised and used automatically by Qpack2.',...
 ];
 %-----------------------------------------------------------------------------
 Q.Z_FIELD = {};
@@ -778,7 +1017,7 @@ I.Z_FIELD = [ ...
 %-----------------------------------------------------------------------------
 Q.Z_SURFACE = {};
 I.Z_SURFACE = [ ...
-'Surface altitude (above reference ellispoid). As the arts WSV with the ',...
+'Surface altitude (above reference ellipsoid). As the arts WSV with the ',...
 'same name.'
 ];
 %-----------------------------------------------------------------------------
