@@ -1,7 +1,7 @@
 % QARTS_DEMO   A simple demonstration of Qarts
 %
-%    Gives an example on basic usage of Qarts. No include files are used, beside
-%    absorption model data, and all settings are done inside the file. 
+%    Gives an example on basic usage of Qarts. All agendas are defined in
+%    the file (agendas.arts not used).
 %
 %    The example simulated Odin-SMR observations around 501 GHz, but 
 %    with a simplified set-up. 
@@ -18,7 +18,6 @@
 % 2005-01-26   Sensor part added by Mattias Ekstrom.
 % 2004-??-??   Created by Patrick Eriksson.
 
-
 function [Q,f,y] = qarts_demo( varargin )
 %
 [ztan] = optargs( varargin, { 30e3 } );
@@ -27,6 +26,10 @@ function [Q,f,y] = qarts_demo( varargin )
 %= Init Q structures
 %
 Q  = qarts;
+%
+Q.INCLUDES              = { fullfile( 'ARTS_INCLUDES', 'general.arts' ), ...
+                            fullfile( 'ARTS_INCLUDES', 'continua.arts' ), ...
+                            fullfile( 'ARTS_INCLUDES', 'planet_earth.arts' ) };
 
 
 %= De-activate parts not used
@@ -44,34 +47,38 @@ Q.OUTPUT_FILE_FORMAT    = 'ascii';
 %
 Q.ATMOSPHERE_DIM        = 1;
 %
-Q.P_GRID                = z2p_simple( [0:500:45e3 46e3:1e3:100e3]' );
+Q.P_GRID                = z2p_simple( [0:500:45e3 46e3:1e3:95e3]' );
 %
 arts_xmldata_path       = atmlab( 'ARTS_XMLDATA_PATH' );
 if isnan( arts_xmldata_path )
-  error('You need to ARTS_XMLDATA_PATH to run this example.');
+  error('You need ARTS_XMLDATA_PATH to run this example.');
 end
 %
-Q.RAW_ATMOSPHERE        = fullfile( arts_xmldata_path, 'atmosphere', ...
-                                                        'fascod', 'tropical' );
+Q.RAW_ATMOSPHERE        = fullfile( arts_xmldata_path, 'planets', 'Earth', ...
+                                            'Fascod', 'tropical', 'tropical' );
 Q.RAW_ATM_EXPAND_1D     = false;
 %
 Q.WIND_U_FIELD          = [];
 Q.WIND_V_FIELD          = [];
 Q.WIND_W_FIELD          = [];
+Q.MAG_U_FIELD           = [];
+Q.MAG_V_FIELD           = [];
+Q.MAG_W_FIELD           = [];
 %
-Q.R_GEOID               = constants( 'EARTH_RADIUS' );
+Q.REFELLIPSOID          = ellipsoidmodels( 'SphericalEarth' );
 Q.Z_SURFACE             = 500;
 
 
 %= To enforce detailed hydrostatic equilibrium 
 %
-% This demands that a latitude is specified, through LAT_GRID.
+% This demands that a geographical position is specified, through LAT/LON_TRUE.
 %
 Q.HSE.ON                = true;
 Q.HSE.P                 = Q.P_GRID(1);
 Q.HSE.ACCURACY          = 1;
 %
-Q.LAT_GRID              = 15;
+Q.LAT_TRUE              = 15;
+Q.LON_TRUE              = -30;
 
 
 %= Absorption
@@ -84,40 +91,42 @@ Q.ABS_SPECIES(4).TAG{2} = 'H2O-PWR98';
 Q.ABS_SPECIES(5).TAG{1} = 'N2-SelfContStandardType';
 %
 Q.ABSORPTION            = 'OnTheFly';  % A simple, but slow, option!
-% abs_n2 is set below
 Q.ABS_LINES_FORMAT      = 'Arts';
 Q.ABS_LINES             = fullfile( atmlab_example_data , 'lines501.4' );
 Q.ABS_LINESHAPE         = 'Voigt_Kuntz6';
 Q.ABS_LINESHAPE_CUTOFF  = -1;
 Q.ABS_LINESHAPE_FACTOR  = 'VVH';
-%
-Q.INCLUDES              = { fullfile( 'ARTS_INCLUDES', 'continua.arts' ) };
 
 
 %= Set RTE variables (refraction is here neglected)
 %
-Q.EMISSION_AGENDA       = { 'emissionPlanck' };
-Q.IY_SPACE_AGENDA       = { 'Ignore(rte_pos)', 'Ignore(rte_los)', ...
+Q.IY_MAIN_AGENDA        = { 'iyEmissionStandard' };
+Q.BLACKBODY_RADIATION_AGENDA = { 'blackbody_radiationPlanck' };
+Q.IY_SPACE_AGENDA       = { 'Ignore(rtp_pos)', 'Ignore(rtp_los)', ...
                             'MatrixCBR(iy,stokes_dim,f_grid)' };
-Q.IY_CLEARSKY_AGENDA    = { 'iyEmissionStandardClearsky' };
-Q.SURFACE_PROP_AGENDA   = { 'Ignore(rte_pos)', 'Ignore(rte_los)', ...
-                           ['InterpAtmFieldToRteGps(surface_skin_t,',...
-                            'atmosphere_dim,','rte_gp_p,rte_gp_lat,',...
-                            'rte_gp_lon,t_field)'], ...
+Q.SURFACE_RTPROP_AGENDA = { 'Ignore(rtp_pos)', 'Ignore(rtp_los)', ...
+                           ['InterpAtmFieldToPosition(out=surface_skin_t,', ...
+                                                         'field=t_field)'], ...
                             'surfaceBlackbody' };
+Q.IY_SURFACE_AGENDA     = { 'iySurfaceRtpropAgenda' };
+Q.IY_AUX_VARS           = [];
 %
-Q.WSMS_BEFORE_RTE       = { 'VectorSet(abs_n2,[0.7808])' };
 Q.YCALC_WSMS            = { 'yCalc' };
 %
-Q.PPATH_LMAX            = 20e3;
-Q.PPATH_STEP_AGENDA     = { 'ppath_stepGeometric' };
+Q.PPATH_LMAX            = 10e3;
+Q.PPATH_STEP_AGENDA     = { 'Ignore(t_field)', 'Ignore(vmr_field)', ... 
+                            'Ignore(f_grid)', ... 
+                            'Ignore(ppath_lraytrace)', 'ppath_stepGeometric' };
+Q.PPATH_AGENDA          = { 'Ignore(rte_pos2)', 'ppathStepByStep' };
+Q.WSMS_AT_START{end+1}  = 'FlagOff( ppath_inside_cloudbox_do )';
 %
 Q.STOKES_DIM            = 1;
-Q.Y_UNIT                = 'RJBT';
+Q.IY_UNIT                = 'RJBT';
 %
 zplat                   = 600e3;
-Q.SENSOR_POS            = Q.R_GEOID + zplat;
-Q.SENSOR_LOS            = geomztan2za( Q.R_GEOID, zplat, ztan );
+Q.SENSOR_POS            = zplat;
+Q.SENSOR_LOS            = geomztan2za( Q.REFELLIPSOID(1), zplat, ztan );
+Q.TRANSMITTER_POS       = [];
 
   
 %= Sensor
@@ -135,6 +144,7 @@ else
   %
   Q.ANTENNA_DIM         = 1;
   Q.MBLOCK_ZA_GRID      = [-0.04:0.02:0.04]';
+  H.ANTENNA_DO          = true;
   H.ANTENNA_LOS         = 0;
   H.ANTENNA_RESPONSE    = fullfile( atmlab_example_data, 'antenna.xml' );
   %
@@ -150,9 +160,9 @@ end
 
 %= Calculate spectrum/spectra
 %
-[y,ydata] = arts_y( Q );
+y = arts_y( Q );
 %
-f = ydata.f;
+f = Q.F_GRID;
 
 
 %= Plot
