@@ -2,7 +2,7 @@
 %
 %    The main features of Qpack2 are demonstrated. The example case is airborne
 %    measurements of ozone at 110.8 GHz. Synthetic measurement data are
-%    generated internally. See the code and intrnal comments for details.
+%    generated internally. See the code and internal comments for details.
 %
 %    Everything is here put into a single file. For practical retrievals it
 %    is probably better to put the definitions of Q (together with O?) in a
@@ -10,6 +10,9 @@
 %    measurement data into the "Y format" (see *qp2_y*) is needed. The
 %    retrieval result is returned in the L2 format produced by *qp2_l2*.
 %
+%    This script focuses on giving an introduction, indicating different
+%    retrieval units and retrieval of other variables. See also *qpack2_demo2*.
+%
 % FORMAT   L2 = qpack2_demo
 %        
 % OUT      L2   L2 data output from *qpack2*.
@@ -18,7 +21,8 @@
 
 function L2 = qpack2_demo
   
-  
+errid = ['atmlab:' mfilename]; 
+
 %- Qarts settings
 %
 Q    = q_demo;           % Local file, found below
@@ -32,16 +36,14 @@ Y = y_demo( Q );         % Local file, found below
 %- Check that all frequencies are OK
 %
 if ~qp2_check_f( Q, Y, 1e3 );
-  error( 'Some mismatch between Q.F_BACKEND and frequencies of spectra.' );
+  error( errid, ...
+            'Some mismatch between Q.F_BACKEND and frequencies of spectra.' );
 end
-%
-[Y.F] = deal( {} );      % The field F is now obselete. {} is used inside 
-                         % qarts and qpack2 to flag undefined fields
 
 
 %- OEM variables
 %
-O = qp2_l2( Q );         % This ensures that OEM returns the varibles needed 
+O = qp2_l2( Q );         % This ensures that OEM returns the variables needed 
 %                          to fill the L2 structure, as defined in Q
 O.linear = false;
 %
@@ -60,13 +62,28 @@ L2 = qpack2( Q, O, Y );
 %- Plot, if no output argument
 %
 if ~nargout
+  
+  % Profiles
+  figure(1),clf
   plot( L2(1).species1_x*1e6, p2z_simple(L2(1).species1_p)/1e3, 'b', ...
         L2(2).species1_x*1e6, p2z_simple(L2(2).species1_p)/1e3, 'r', ...
         L2(1).species1_xa*1e6, p2z_simple(L2(1).species1_p)/1e3, 'k-' );
   xlabel( 'Ozone [VMR]' );
   ylabel( 'Approximate altitude [km]' );
+  axis( [ 0 8 10 90 ] )
   legend( 'Retrieval 1', 'Retrieval 2', 'True and a priori' );
+
+  % Spectra
+  figure(2),clf
+  h=plot( L2(1).f/1e9, L2(1).y, 'k.', L2(2).f/1e9, L2(2).y, 'k.', ...
+          L2(1).f/1e9, L2(1).yf, 'b-', L2(2).f/1e9, L2(2).yf, 'r-', ...
+          L2(1).f/1e9, L2(1).bl, 'b-.', L2(2).f/1e9, L2(2).bl, 'r-.' );
+  xlabel( 'Frequency [GHz]' );
+  ylabel( 'Tb [K]' );
+  axis( [ min(L2(1).f/1e9) max(L2(1).f/1e9) 0 18 ] )
+  legend( h(3:end), 'Fitted 1', 'Fitted 2', 'Baseline 1', 'Baseline 2' );
 end
+
 return
 %-----------------------------------------------------------------------------
 %-----------------------------------------------------------------------------
@@ -78,49 +95,62 @@ return
 
 function Q = q_demo
  
+errid = ['atmlab:' mfilename];
 %- Atmlab settings
 %
 arts_xmldata_path = atmlab( 'ARTS_XMLDATA_PATH' );
 arts_includes     = atmlab( 'ARTS_INCLUDES' );
 if isnan( arts_xmldata_path ) 
-  error( 'You need to set ARTS_XMLDATA_PATH to run this exmaple.' );
+  error( errid,'You need to set ARTS_XMLDATA_PATH to run this exmaple.' );
 end
 if isnan( arts_includes )
-  error( 'You need to ARTS_INCLUDES to run this example.' );
+  error( erird,'You need to ARTS_INCLUDES to run this example.' );
 end                                                      
 %
-fascod = fullfile( arts_xmldata_path, 'atmosphere', 'fascod' );
+fascod = fullfile( arts_xmldata_path, 'planets', 'Earth', 'Fascod' );
 
 
 %- Init Q
 %
 Q = qarts;
-
-
-%- General 
 %
-Q.INCLUDES            = { fullfile( arts_includes, 'general.arts' ), ...
-                          fullfile( arts_includes, 'continua.arts' ) };
+Q.INCLUDES            = { fullfile( 'ARTS_INCLUDES', 'general.arts' ), ...
+                          fullfile( 'ARTS_INCLUDES', 'agendas.arts' ), ...
+                          fullfile( 'ARTS_INCLUDES', 'continua.arts' ), ...
+                          fullfile( 'ARTS_INCLUDES', 'planet_earth.arts' ) };
 Q.ATMOSPHERE_DIM      = 1;
 Q.STOKES_DIM          = 1;
 Q.J_DO                = true;
 Q.CLOUDBOX_DO         = false;
 
 
+%= Define agendas
+%
+% Here we do it by using the predefined agenda templates 
+%   (found in arts/controlfiles/general/agendas.arts)
+% This works only if the pre-defined agenda is names following the pattern:
+%   name_of_agenda__(Something)
+%
+Q.PPATH_AGENDA               = { 'ppath_agenda__FollowSensorLosPath'   };
+Q.PPATH_STEP_AGENDA          = { 'ppath_step_agenda__GeometricPath'    };
+Q.BLACKBODY_RADIATION_AGENDA = { 'blackbody_radiation_agenda__Planck'  };
+Q.IY_SPACE_AGENDA            = { 'iy_space_agenda__CosmicBackground'   };
+Q.IY_SURFACE_AGENDA          = { 'iy_surface_agenda__UseSurfaceRtprop' };
+Q.IY_MAIN_AGENDA             = { 'iy_main_agenda__Emission'            };
+
+
 %- Radiative transfer
 %
-Q.Y_UNIT              = 'RJBT'; 
+Q.IY_UNIT             = 'RJBT'; 
 Q.YCALC_WSMS          = { 'yCalc' };
 %
 Q.PPATH_LMAX          = 250;
-Q.PPATH_STEP_AGENDA   = { 'ppath_stepGeometric' };
 
 
 %- Surface
 %
-Q.R_GEOID            = constants( 'EARTH_RADIUS' );
-Q.Z_SURFACE          = 5e3;          % Just a dummy value. A 10 km
-                                     % observation altitude is assumed here
+Q.Z_SURFACE           = 1e3;          % Just a dummy value. A 10 km
+                                      % observation altitude is assumed here
 
 
 %- Absorption
@@ -135,7 +165,7 @@ Q.ABS_NLS             = [];
 %
 z_toa                 = 95e3;
 %
-Q.P_GRID              = z2p_simple( Q.Z_SURFACE-1e3 : 250 : z_toa )';
+Q.P_GRID              = z2p_simple( Q.Z_SURFACE-1e3 : 2e3 : z_toa )';
 
 
 
@@ -152,7 +182,7 @@ H.SENSOR_NORM         = true;
 %
 H.BACKEND_DO          = true;
 df                    = 0.5e6;
-H.F_BACKEND           = [ min(Q.F_GRID)+df : df : max(Q.F_GRID)-df ]';
+H.F_BACKEND           = ( min(Q.F_GRID)+df : df : max(Q.F_GRID)-df )';
 %
 B.name                = 'Spectrometer channel response function';
 B.gridnames           = { 'Frequency' };
@@ -173,26 +203,26 @@ Q.MBLOCK_ZA_GRID      = 0;
 
 %- Correlation of thermal noise 
 %
-f    = H.F_BACKEND;
-cl   = 1.4 * ( f(2) - f(1) );
-cfun = 'gau';
-cco  = 0.05;
+f              = H.F_BACKEND;
+cl             = 1.4 * ( f(2) - f(1) );
+cfun           = 'gau';
+cco            = 0.05;
 %
-Q.TNOISE_C = covmat1d_from_cfun( f, [], cfun, cl, cco );
+Q.TNOISE_C     = covmat1d_from_cfun( f, [], cfun, cl, cco );
 %
 clear H f
 
 
 %- Define L2 structure (beside retrieval quantities below)
 %
-Q.L2_EXTRA = { 'cost', 'dx', 'xa', 'y', 'yf', 'bl', 'ptz', 'mresp', 'A', ...
-               'e', 'eo', 'es', 'date' };
+Q.L2_EXTRA     = { 'cost', 'dx', 'xa', 'y', 'yf', 'bl', 'ptz', ...
+                   'mresp', 'A', 'e', 'eo', 'es', 'date' };
 
 
 %- Temperature
 %
-Q.T.RETRIEVE = false;
-Q.T.ATMDATA  = gf_artsxml( fullfile( arts_xmldata_path, 'climatology', ...
+Q.T.RETRIEVE   = false;
+Q.T.ATMDATA    = gf_artsxml( fullfile( arts_xmldata_path, 'climatology', ...
                         'msis90', 'msis90.t.xml' ), 'Temperature', 't_field' );
 
 %- Determine altitudes through HSE
@@ -208,9 +238,14 @@ Q.HSE.ACCURACY = 0.1;
 Q.ABS_SPECIES(1).TAG      = { 'O3' };
 Q.ABS_SPECIES(1).RETRIEVE = true;
 Q.ABS_SPECIES(1).L2       = true;
-Q.ABS_SPECIES(1).GRIDS    = { z2p_simple(Q.Z_SURFACE+1e3:2e3:z_toa)', [], [] };
+Q.ABS_SPECIES(1).GRIDS    = { Q.P_GRID, [], [] };
 Q.ABS_SPECIES(1).ATMDATA  = gf_artsxml( fullfile( fascod, ...
-                            'midlatitude-winter.O3.xml' ), 'O3', 'vmr_field' );
+      'midlatitude-winter', 'midlatitude-winter.O3.xml' ), 'O3', 'vmr_field' );
+%
+% If you don't apply a min value (by MINMAX), you could need to active this:
+%Q.VMR_NEGATIVE_OK = true;
+%
+% For demonstration, setting for several units are provided:
 switch 1
  case 1  % Constant VMR
   Q.ABS_SPECIES(1).UNIT     = 'vmr';
@@ -219,6 +254,7 @@ switch 1
                                                'lin', 0.2, 0.00, @log10 ) + ...
                      covmat1d_from_cfun( Q.ABS_SPECIES(1).GRIDS{1}, 0.3e-6, ...
                                                'lin', 0.5, 0.00, @log10 );
+   Q.ABS_SPECIES(1).MINMAX  = 1e-12;
  case 2 % Constant rel
   Q.ABS_SPECIES(1).UNIT     = 'rel';
   Q.ABS_SPECIES(1).SX       = ...
@@ -226,6 +262,7 @@ switch 1
                                                'lin', 0.2, 0.00, @log10 ) + ...
                      covmat1d_from_cfun( Q.ABS_SPECIES(1).GRIDS{1}, 0.1, ...
                                                'lin', 0.5, 0.00, @log10 );
+  Q.ABS_SPECIES(1).MINMAX  = 1e-6;
  case 3 % Mimic case 2 in vmr
   Q.ABS_SPECIES(1).UNIT     = 'vmr';
   Q.ABS_SPECIES(1).SX       = ...
@@ -237,7 +274,7 @@ switch 1
                                        [ Q.ABS_SPECIES(1).ATMDATA.GRID1, ...
                                    0.1 * Q.ABS_SPECIES(1).ATMDATA.DATA ],...
                                                'lin', 0.5, 0.00, @log10 );
-
+  Q.ABS_SPECIES(1).MINMAX  = 1e-12;
  case 4 % Constant logrel
   Q.ABS_SPECIES(1).UNIT     = 'logrel';
   Q.ABS_SPECIES(1).SX       = ...
@@ -245,6 +282,7 @@ switch 1
                                                'lin', 0.2, 0.00, @log10 ) + ...
                      covmat1d_from_cfun( Q.ABS_SPECIES(1).GRIDS{1}, 0.1, ...
                                                'lin', 0.5, 0.00, @log10 );
+  Q.ABS_SPECIES(1).MINMAX  = 1e-6;
 end  
   
   
@@ -256,40 +294,56 @@ end
 Q.ABS_SPECIES(2).TAG      = { 'H2O' };
 Q.ABS_SPECIES(2).RETRIEVE = false;
 Q.ABS_SPECIES(2).ATMDATA  = gf_artsxml( fullfile( fascod, ...
-                          'midlatitude-winter.H2O.xml' ), 'H2O', 'vmr_field' );
+    'midlatitude-winter', 'midlatitude-winter.H2O.xml' ), 'H2O', 'vmr_field' );
 
-% O2 and N2 not active, to make example somewhat faster
-if 0
-%- Oxygen
-%
-Q.ABS_SPECIES(3).TAG      = { 'O2-PWR93' };
-Q.ABS_SPECIES(3).RETRIEVE = false;
-Q.ABS_SPECIES(3).ATMDATA  = gf_artsxml( fullfile( fascod, ...
-                            'midlatitude-winter.O2.xml' ), 'O2', 'vmr_field' );
 
-%- Nitrogen
+
+%- Wind
 %
-Q.ABS_SPECIES(4).TAG      = { 'N2-SelfContStandardType' };
-Q.ABS_SPECIES(4).RETRIEVE = false;
-Q.ABS_SPECIES(4).ATMDATA  = gf_artsxml( fullfile( fascod, ...
-                            'midlatitude-winter.N2.xml' ), 'N2', 'vmr_field' );
+% Here demonstrated for v-component, that should the component of main
+% concern for ground-based instruments. This component can be seen as the
+% part of the horizontal wind going along the viewing direction, where
+% positive values mean a movement away from the sensor.
+%
+Q.WIND_V_FIELD    = [];      % This is a short-cut for zero wind.
+%
+Q.WIND_V.RETRIEVE = false;   % Set to true to activate retrieval
+Q.WIND_V.L2       = true;
+Q.WIND_V.GRIDS    = { Q.P_GRID(1:2:end), [], [] };
+Q.WIND_V.SX       = covmat1d_from_cfun( Q.WIND_V(1).GRIDS{1}, 40, ...
+                                                    'lin', 0.5, 0.00, @log10 );
+if Q.WIND_V.RETRIEVE
+  Q.WSMS_AT_START{end+1} = 'IndexSet(abs_f_interp_order,3)';
 end
 
 
 
-%- Frequency (shift retrieval here, shift+stretch also possible)
+%- Pointing
 %
-Q.FFIT.RETRIEVE           = true;
-Q.FFIT.DF                 = 25e3; 
-Q.FFIT.ORDER              = 0;
-Q.FFIT.SX                 = 50e3^2;  
-Q.FFIT.L2                 = true;
+% Here just included for testing purposes, of little interest for ground-based
+% spectrometers. 
+%
+Q.POINTING.RETRIEVE       = false;
+Q.POINTING.DZA            = 0.1; 
+Q.POINTING.POLY_ORDER     = 0;
+Q.POINTING.CALCMODE       = 'recalc';
+Q.POINTING.SX             = 1;  
+Q.POINTING.L2             = true;
 
-%Q.FFIT.RETRIEVE           = true;
-%Q.FFIT.DF                 = 25e3; 
-%Q.FFIT.ORDER              = 1;
-%Q.FFIT.SX                 = [300e3^2 0;0 100e3^2]; 
-%Q.FFIT.L2                 = true;
+
+%- Frequency shift
+%
+Q.FSHIFTFIT.RETRIEVE      = true;
+Q.FSHIFTFIT.DF            = 25e3; 
+Q.FSHIFTFIT.SX            = 50e3^2;  
+Q.FSHIFTFIT.L2            = true;
+
+%- Frequency stretch
+%
+Q.FSTRETCHFIT.RETRIEVE    = false;   % Set to true to activate retrieval
+Q.FSTRETCHFIT.DF          = 25e3; 
+Q.FSTRETCHFIT.SX          = 50e3^2;  
+Q.FSTRETCHFIT.L2          = true;
 
 
 %- Polyfit
@@ -304,6 +358,17 @@ Q.POLYFIT.SX1             = 0.5^2;
 Q.POLYFIT.SX2             = 0.2^2;
 Q.POLYFIT.SX3             = 0.1^2; 
 
+
+%- Sinefit
+%
+% Here demonstrated with two period lengths
+%
+Q.SINEFIT.RETRIEVE        = false;   % Set to true to activate retrieval
+Q.SINEFIT.PERIODS         = [ 75e3 200e3 ]';
+Q.SINEFIT.L2              = true;
+Q.SINEFIT.SX1             = 0.2^2; 
+Q.SINEFIT.SX2             = 0.4^2; 
+
 return
 %-----------------------------------------------------------------------------
 %-----------------------------------------------------------------------------
@@ -340,7 +405,7 @@ Y.LONGITUDE = exp(1);
 % An airborn measurement assumed here
 %
 Y.Z_PLATFORM = 10.5e3;
-Y.ZA         = 70;
+Y.ZA         = 50;
 
 % Reference point for hydrostatic equilibrium
 %
@@ -353,7 +418,7 @@ Y.F = Q.SENSOR_RESPONSE.F_BACKEND;
 
 % Thermal noise standard deviation
 %
-Y.TNOISE = 0.05;
+Y.TNOISE = 0.1;
 % To test varying noise
 %Y.TNOISE = linspace( 0.03, 0.07, length(Y.F) )';
 
@@ -369,6 +434,7 @@ Y(2) = Y(1);
 Y(2).LONGITUDE = pi;
 Y(2).ZA        = 45;
 
+
 % Calculate simulated spectra
 %
 Y = qpack2( Q, oem, Y );            % Dummy oem structure OK here 
@@ -384,3 +450,4 @@ end
 % Add a constant "baseline shift" for measurement 2
 %
 Y(2).Y = Y(2).Y + 1;
+
