@@ -30,10 +30,10 @@ function [data,lat,lon] = binning_fast(in,lonspace)
 %
 %                             or
 %                  newlat        [lat vector]      bin into new lat grid
-%                  newlon        [lat vector]      bin into new lon grid
+%                  newlon        [lon vector]      bin into new lon grid
 %
 %              OPTIONAL
-%                  region        [blcorner,trcorner] (lt1,ln1,lt2,ln2)
+%                  region        [blcorner,trcorner] (lat1,lon1,lat2,lon2)
 %
 %
 %          If region is given, the function will only bin the data within the
@@ -69,6 +69,7 @@ function [data,lat,lon] = binning_fast(in,lonspace)
 %       2) A useful function to get statistics (e.g numel, mean, sum, etc) on
 %       the binned data is binned_statistics.
 %
+% See also: bin, bin_nd, binned_statistics
 %
 % Created by Oliver Lemke and Salomon Eliasson
 % $Id$
@@ -99,7 +100,7 @@ indata = in.data;
 
 %% GET COUNTS
 data = cell(length(lat), length(lon));
-counts = zeros (size(data), class(indata));
+counts = zeros (size(data), 'uint32');
 for i = 1:size(indata,1)
     ilat = latindex(i);
     ilon = lonindex(i);
@@ -120,7 +121,7 @@ for i = 1:size(indata,1)
     data{ilat, ilon}(counts(ilat, ilon),:) = indata(i,:);
     counts(ilat, ilon) = counts(ilat, ilon) - 1;
 end
-
+end
 %% Subfunctions
 % ||
 % VV
@@ -139,7 +140,8 @@ if isequal(numel(in.data),numel(in.lat),numel(in.lon))
 end
 
 assert(isequal(size(in.data,1),size(in.lat,1),size(in.lon,1)),...
-    errId,'data,lat,lon must all be the same size')
+    errId, ['data,lat,lon must all have the same first dimension. Found: ' ...
+            'data %d, lat %d, lon %d'], size(in.data, 1), size(in.lat, 1), size(in.lon, 1));
 
 if isfield(in,'newlon')
     str = 'fields ''newlat'' and ''newlon''';
@@ -166,6 +168,7 @@ if isfield(in,'newlon')
     in.region = [min(in.newlat)-dlt,min(in.newlon)-dln,max(in.newlat)+dlt,max(in.newlon)+dln];
 end
 
+end
 function in = regionchop(in)
 % Get rid of all data outside of region
 
@@ -180,12 +183,13 @@ in.lat = in.lat(index);
 in.lon = in.lon(index);
 in.data = in.data(index,:);
 
+end
 function [in,lat,lon] = outputlatlons(in,lonspace)
 %% fix the latlons
 % Sets up lat lon and adjusts in.lon to the requested (if requested)
 % longitude regime (0:360 or -180:180)
 %
-errId = 'atmlab:binning_fast:badInput';
+errId = ['atmlab:' mfilename ':badInput'];
 
 testmore = in.lon>180; %logical for any lons > 180
 testless = in.lon<0; %logical for any lons < 0
@@ -222,5 +226,9 @@ d = in.gridsize;
 assert(numel(d)<=2,errId,'''gridsize'' should contain 1 or 2 values')
 
 if isscalar(d), d = [d,d]; end
+assert(isnumeric(in.region),errId,'in.region must be a numeric vector of coordinates')
+
 lat = in.region(1)+0.5*d(1):d(1):in.region(3)-0.5*d(1);
-lon = in.region(2)+0.5*d(2):d(2):in.region(4)-0.5*d(2);
\ No newline at end of file
+lon = in.region(2)+0.5*d(2):d(2):in.region(4)-0.5*d(2);
+
+end
